/* The system doesn't have <fnmatch.h>.  Use our fnmatch.h emulation.  */
#include "fnmatch_.h"
